<?php
class responslidesjs {

	const XML_HEADER = '<?xml version="1.0" encoding="' . PLX_CHARSET . '"?>' . PHP_EOL;
	public $config = null; # fichier des données
	public $aSlides = array(); # tableau des slides

	public function __construct() {
		if(defined('PLX_CONF')) # version PluXml < 5.1.7
			$this->config = dirname(PLX_CONF).'/responslidesjs.config.xml';
		else # version PluXml >= 5.1.7
			$this->config = PLX_ROOT . PLX_CONFIG_PATH . 'plugins/responslidesjs.config.xml';
	}

	/**
	* Méthode qui parse le fichier des slides et alimente le tableau aSlides
	*
	* @param filename emplacement du fichier XML des slides
	* @return null
	* @author Stéphane F
	**/
	public function getSlides() {
		if(!is_file($this->config)) {
			return;
		}

	 	# Mise en place du parseur XML
		$data = implode('',file($this->config));
		$parser = xml_parser_create(PLX_CHARSET);
		xml_parser_set_option($parser,XML_OPTION_CASE_FOLDING,0);
		xml_parser_set_option($parser,XML_OPTION_SKIP_WHITE,0);
		xml_parse_into_struct($parser,$data,$values,$iTags);
		xml_parser_free($parser);

		if(isset($iTags['slide']) AND isset($iTags['title'])) {
			$nb = sizeof($iTags['title']);
			$size = ceil(sizeof($iTags['slide']) / $nb);
			for($i=0;$i<$nb;$i++) {
				$attributes = $values[$iTags['slide'][$i*$size]]['attributes'];
				$this->aSlides[$attributes['number']] = array(
					'title'			=> plxUtils::getValue($values[$iTags['title'][$i]]['value']),
					'onclick'		=> plxUtils::getValue($values[$iTags['onclick'][$i]]['value']),
					'description'	=> plxUtils::getValue($values[$iTags['description'][$i]]['value']),
					'url'			=> plxUtils::getValue($values[$iTags['url'][$i]]['value']), # url de l'image
					'active'		=> isset($attributes['active']) ? $attributes['active'] : '1', # dans le menu
				);
			}
		}
	}

	/**
	*  Méthode qui retourne le prochain id d'un slide
	*
	* @return string  id d'un nouveau slide sous la forme 001
	* @author Stephane F.
	**/
	public function nextIdSlide(){
		if(is_array($this->aSlides)) {
			$idx = key(array_slice($this->aSlides, -1, 1, true));
			return str_pad($idx+1,3, '0', STR_PAD_LEFT);
		} else {
			return '001';
		}
	}

	/**
	* Méthode qui édite le fichier XML des slides selon le tableau $content
	*
	* @param content tableau multidimensionnel des catégories
	* @param action permet de forcer la mise àjour du fichier
	* @return string
	* @author Stephane F
	**/
	public function editSlides($content, $action=false){
		$save = $this->aSlides;
		if(!empty($content['selection'])) {
			if($content['selection'] == 'delete' and !empty($content['idSlide'])) {
				# suppression
				foreach($content['idSlide'] as $slide_id) {
					unset($this->aSlides[$slide_id]);# suppression du parametre
				}
				$action = true;
			} elseif(
				(!empty($content['selection'][0]) OR !empty($content['selection'][1])) AND
				!empty($content['idFile'])
			) {
				# ajout d'un nouveau slide à partir du gestionnaire de médias
				$plxAdmin = plxAdmin::getInstance();
				$root = $plxAdmin->aConf['medias'];
				if(!empty($content['folder']) and $content['folder'] != '.') {
					$root .= $content['folder'];
				}

				foreach($content['idFile'] as $filename){
					$slide_id = $this->nextIdSlide();
					$this->aSlides[$slide_id] = array(
						'url'		=> $root . $filename,
						'title'		=> str_replace(array('-','_'), ' ',preg_replace('@\.\w+$@', '', $filename)),  //On supprime l'extention et on remplace les '-'' et '_'' par des espaces
						'ordre'		=> intval($slide_id),
						'active'	=> 0,
						'onclick'	=> '',
					);
				}
				$action = true;
			}
		} elseif(isset($content['update'])) {
			# mise à jour de la liste
			foreach($content['slideNum'] as $slide_id){
				if($content[$slide_id.'_url']!='') {
					$this->aSlides[$slide_id] = array(
						'url'			=> trim($content[$slide_id.'_url']),
						'title'			=> trim(strip_tags($content[$slide_id.'_title'])),
						'description'	=> trim(strip_tags($content[$slide_id.'_description'])),
						'ordre'			=> intval($content[$slide_id.'_ordre']),
						'active'		=> intval($content[$slide_id.'_active']),
						'onclick'		=> trim($content[$slide_id.'_onclick']),
					);
				}
			}
			# On va trier les clés selon l'ordre choisi
			if(sizeof($this->aSlides) > 1) {
				uasort($this->aSlides, function($a, $b) {
					return intval($a['ordre']) - intval($b['ordre']);
				});
			}
			$action = true;
		}

		if(empty($action)) {
			return;
		}

		# sauvegarde
		# On génére le fichier XML
		ob_start();
?>
<document>
<?php
		$slide_id = 0;# On renumérote l'ordre
		foreach($this->aSlides as $slide) {
?>
	<slide number="<?= str_pad(++$slide_id, 3, "0", STR_PAD_LEFT) ?>" active="<?= $slide['active'] ?>">
<?php
			foreach(array('url', 'title', 'onclick', 'description') as $tag) {
?>
		<<?= $tag ?>><![CDATA[<?= plxUtils::cdataCheck($slide[$tag]) ?>]]></<?= $tag ?>>
<?php
			}
?>
	</slide>
<?php
		}
?>
</document>
<?php
		# On écrit le fichier
		if(plxUtils::write(self::XML_HEADER . ob_get_clean(), $this->config)) {
			return plxMsg::Info(L_SAVE_SUCCESSFUL);
		} else {
			$this->aSlides = $save;
			return plxMsg::Error(L_SAVE_ERR . ' ' . $this->config);
		}
	}
}
