<?php
/**
 * Plugin plxResponsiveSlidesJs
 * @author Stephane F
 * @author Jean-Pierre Pourrez "bazooka07"
 * @fourcheur Thomas I
 **/

# https://github.com/viljamis/ResponsiveSlides.js - version 1.55
# https://github.com/viljamis/ResponsiveSlides.js/archive/v1.55.zip

include __DIR__ . '/class.plx.responslidesjs.php';

class plxResponsiveSlidesJs extends plxPlugin {
	const ADMIN_HOOKS = array(
		'AdminMediasTop',
		'AdminMediasPrepend',
	);
	const SITE_HOOKS = array(
		'ThemeEndHead',
		'ThemeEndBody',
		'ResponsiveSlidesJs',
	);
	const BEGIN_CODE = '<?php' . PHP_EOL;
	const END_CODE = PHP_EOL . '?>';

	const JQUERY_VERSION = '3.5.1';

	const LIB_FOLDER = '/ResponsiveSlides.js/';
	const LIB_PATH_JS = __CLASS__ . self::LIB_FOLDER;
	const JS_DEFAULT_VALUES = array(
		'auto'				=> true,			// Boolean: Animate automatically, true or false
		'speed'				=> 500,				// Integer: Speed of the transition, in milliseconds
		'timeout'			=> 4000,			// Integer: Time between slide transitions, in milliseconds
		'pager'				=> false,			// Boolean: Show pager, true or false
		'nav'				=> false,			// Boolean: Show navigation, true or false
		'random'			=> false,			// Boolean: Randomize the order of the slides, true or false
		'pause'				=> false,			// Boolean: Pause on hover, true or false
		'pauseControls'		=> true,			// Boolean: Pause when hovering controls, true or false
		'prevText'			=> 'Previous',		// String: Text for the "previous" button
		'nextText'			=> 'Next',			// String: Text for the "next" button
		'maxwidth'			=> 0,				// Integer: Max-width of the slideshow, in pixels
		# 'navContainer'	=> 'ul',			// Selector: Where controls should be appended to, default is after the 'ul'
		# 'manualControls'	=> '',				// Selector: Declare custom pager navigation
		'namespace'			=> 'rslides',		// String: Change the default namespace used
		# 'before'			=> function() {},	// Function: Before callback
		# 'after'			=> function() {},	// Function: After callback
	);
	const EXTRA_VALUES = array(
		'fill'		=> true,
		'menu'		=> '',
		'posm'		=> 0,
		'lynx'		=> false,
		'width'		=> '100%',
		'height'	=> '',
		'maxheight'	=> '',
	);

	public $responslidesjs = null; # objet responslidesjs

	public function __construct($default_lang) {
		# appel du constructeur de la classe plxPlugin (obligatoire)
		parent::__construct($default_lang);

		# Autorisation d'accès à l'administration du plugin#, PROFIL_MODERATOR, PROFIL_EDITOR, PROFIL_WRITER
		$this->setAdminProfil(PROFIL_ADMIN, PROFIL_MANAGER);

		# Autorisation d'acces à la configuration du plugin
		$this-> setConfigProfil(PROFIL_ADMIN, PROFIL_MANAGER);

		$this->responslidesjs = new responslidesjs();
		$this->responslidesjs->getSlides();

		# Personnalisation du menu
		$this->setAdminMenu(
			$this->getParam('menu') != '' ? $this->getParam('menu') : $this->getInfo('title'),
			$this->getParam('posm') != '0' ? $this->getParam('posm') : null,
			$this->getInfo('description')
		);

		# déclaration des hooks
		if(defined('PLX_ADMIN')) {
			foreach(self::ADMIN_HOOKS as $hook) {
				$this->addHook($hook, $hook);
			}
		} elseif(!empty($this->responslidesjs->aSlides)) {
			foreach(self::SITE_HOOKS as $hook) {
				$this->addHook($hook, $hook);
			}
		}
	}

	/*
	public function OnActivate() {
		$filename = PLX_ROOT . PLX_CONFIG_PATH . 'plugins/' . __CLASS__ . '.site.css';
		if(!file_exists($filename) and !copy(__DIR__ . self::LIB_FOLDER . 'responsiveslides-styles.css', $filename)) {
			plxMsg::Error($this->getLang('UNABLE_CSS_COPY'));
			return;
		}
	}
	*/

	public function hasParam($name) {
		return isset($this->aParams[$name]);
	}

	public function AdminMediasTop() {
		echo self::BEGIN_CODE;
?>
$selectionList = array_merge($selectionList, array(
	'ResponsiveSlidesJs'	=> array(
		'responslidesjs_add' => '<?= $this->getLang('L_ADD') ?>'
	)
));
<?php
		echo self::END_CODE;
	}

	public function AdminMediasPrepend(){
		if(isset($_POST['selection']) AND ($_POST['selection'] == 'responslidesjs_add') AND isset($_POST['idFile'])) {
			$this->responslidesjs->editSlides($_POST);
			header('Location: medias.php');
			exit;
		}
	}

	public function ResponsiveSlidesJs() {
		if(empty($this->responslidesjs->aSlides)) {
			return;
		}
?>
	<div class="rslides_container">
		<ul class="rslides" id="responsiveslides">
<?php
	foreach($this->responslidesjs->aSlides as $slide) {
		if(empty($slide['active'])) {
			continue;
		}

		// image active
?>
			<li>
				<img class="rslidesfill" src="<?= plxUtils::strCheck($slide['url']) ?>" title="<?= plxUtils::strCheck($slide['title']) ?>" alt="<?= strip_tags($slide['description']) ?>" />
<?php
		if(!empty($this->getParam('fill'))) {
			# On utilise comme image de fond background-image
			$url = plxUtils::getRacine() . plxUtils::strCheck($slide['url']);
?>
				<div class="rslidesfill" style="background-image:url(<?= $url ?>);"></div>
<?php
		}

		$caption = trim($slide['description']);
		if(!empty($caption)) {
			if(!empty($slide['onclick'])) {
				$innerHTML = '<a href="' . plxUtils::strCheck($slide['onclick']) . '">' . $caption . '</a>"';
			} elseif(!empty($this->getParam('lynx'))) {
				$innerHTML = '<a href="' . plxUtils::strCheck($slide['url']) . '">' . $caption . '</a>"';
			} else {
				$innerHTML = $caption;
			}
?>
				<p class="caption"><?= $innerHTML ?></p>
<?php
		}
?>
			</li>
<?php
	}
?>
		</ul>
	</div>
<?php
	}

	public function ThemeEndHead() {
		$rules = array(
		);
		foreach(array('width', 'height', 'max-height') as $param) {
			$value = $this->getParam(str_replace('-', '', $param));
			if(!empty($value)) {
				$rules[] = $param . ': ' . $value . ';';
			}
		}

		if(empty($rules)) {
			return;
		}
?>
	<style type="text/css">
		.rslides_container,
		.rslides_container .rslidesfill {
<?= implode(PHP_EOL, $rules) . PHP_EOL; ?>
		}
	</style>
<?php
	}

	public function ThemeEndBody() {
		$params = array();
		foreach(self::JS_DEFAULT_VALUES as $key=>$default) {
			$value = $this->getParam($key);
			if(is_bool($default)) {
				$value = !empty($value);
				if($value !== $default) {
					$params[] =  $key . ': ' . ($value ? 'true' : 'false');
				}
			} elseif(is_numeric($default)) {
				$value = intval($value);
				if($value != $default and $value > 0) {
					$params[] = $key . ': ' . $value;
				}
			} elseif(!empty($value)) {
				$params[] = $key . ': \'' . addslashes($value) . '\'';
			}
		}
?>
	<script type="text/javascript">
		(function() {
			'use strict';
			const params = {
<?= implode(',' . PHP_EOL, $params) . PHP_EOL ?>
			};

			function init() {
				const script = document.createElement('SCRIPT');
				script.src = '<?= PLX_PLUGINS . self::LIB_PATH_JS ?>responsiveslides.min.js';
				script.onload = function() {
					console.log('Launching responsiveSlides');
					$('#responsiveslides').responsiveSlides(params);
				};
				document.head.appendChild(script);
			}

			if (typeof jQuery !== 'function') {
				var isLoading = false;
				for(var i=0, iMax = document.scripts.length; i<iMax; i++) {
					const s = document.scripts[i];
					if(s.hasAttribute('src') && /\/jquery[-.\d]*(?:\.min)?\.js$/i.test(s.src)) {
						isLoading = true;
						console.log(s.src + ' is loading by an other script...');
						init();
						break;
					}
				}
				if(!isLoading) {
					const script = document.createElement('SCRIPT');
					script.src = '<?= PLX_PLUGINS . __CLASS__ ?>/jquery-<?= self::JQUERY_VERSION ?>.min.js';
					document.head.appendChild(script);
					console.log('Loading ' + script.src + '...');
				}
			}

		    // window.addEventListener('DOMContentLoaded', init, false);
			window.addEventListener('load', init, false);
		})();
	</script>
<?php
	}
}
?>
